==> kubernetes-model-core-4.13.2-sources.jar: annotations/io/fabric8/kubernetes/api/model/ContainerStateWaitingFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import java.lang.StringBuffer;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

public class ContainerStateWaitingFluentImpl<A extends ContainerStateWaitingFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements ContainerStateWaitingFluent<A> {

    private String message;
    private String reason;

    public ContainerStateWaitingFluentImpl() { 
    }


    public ContainerStateWaitingFluentImpl(ContainerStateWaiting instance) { 
        this.withMessage(instance.getMessage()); 
        this.withReason(instance.getReason()); 
    }


    public String getMessage() {
        return this.message;
    }

    public A withMessage(String message) {
        this.message=message; return (A) this;
    }

    public Boolean hasMessage() {
        return this.message != null;
    }

    public A withNewMessage(String arg1) {
        return (A)withMessage(new String(arg1));
    }

    public A withNewMessage(StringBuilder arg1) {
        return (A)withMessage(new String(arg1));
    }

    public A withNewMessage(StringBuffer arg1) {
        return (A)withMessage(new String(arg1));
    }

    public String getReason() {
        return this.reason;
    }

    public A withReason(String reason) {
        this.reason=reason; return (A) this;
    }

    public Boolean hasReason() {
        return this.reason != null;
    }

    public A withNewReason(String arg1) {
        return (A)withReason(new String(arg1));
    }

    public A withNewReason(StringBuilder arg1) {
        return (A)withReason(new String(arg1));
    }

    public A withNewReason(StringBuffer arg1) {
        return (A)withReason(new String(arg1));
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        ContainerStateWaitingFluentImpl that = (ContainerStateWaitingFluentImpl) o;
        if (message != null ? !message.equals(that.message) :that.message != null) return false;
        if (reason != null ? !reason.equals(that.reason) :that.reason != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(message,  reason,  super.hashCode());
    }

}

==> kubernetes-model-core-5.3.1-sources.jar: annotations/io/fabric8/kubernetes/api/model/ContainerStateWaitingFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import java.lang.StringBuffer;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

public class ContainerStateWaitingFluentImpl<A extends ContainerStateWaitingFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements ContainerStateWaitingFluent<A> {

    private String message;
    private String reason;

    public ContainerStateWaitingFluentImpl() {
    }

    public ContainerStateWaitingFluentImpl(ContainerStateWaiting instance) {
        this.withMessage(instance.getMessage()); 
        this.withReason(instance.getReason()); 
    }

    public String getMessage() {
        return this.message;
    }

    public A withMessage(String message) {
        this.message=message; return (A) this;
    }

    public Boolean hasMessage() {
        return this.message != null;
    }

    public A withNewMessage(StringBuilder arg1) {
        return (A)withMessage(new String(arg1));
    }

    public A withNewMessage(int[] arg1,int arg2,int arg3) {
        return (A)withMessage(new String(arg1, arg2, arg3));
    }

    public A withNewMessage(char[] arg1) {
        return (A)withMessage(new String(arg1));
    }

    public A withNewMessage(StringBuffer arg1) {
        return (A)withMessage(new String(arg1));
    }

    public A withNewMessage(byte[] arg1,int arg2) {
        return (A)withMessage(new String(arg1, arg2));
    }

    public A withNewMessage(byte[] arg1) {
        return (A)withMessage(new String(arg1));
    }

    public A withNewMessage(char[] arg1,int arg2,int arg3) {
        return (A)withMessage(new String(arg1, arg2, arg3));
    }

    public A withNewMessage(byte[] arg1,int arg2,int arg3) {
        return (A)withMessage(new String(arg1, arg2, arg3));
    }

    public A withNewMessage(byte[] arg1,int arg2,int arg3,int arg4) {
        return (A)withMessage(new String(arg1, arg2, arg3, arg4));
    }

    public A withNewMessage(String arg1) {
        return (A)withMessage(new String(arg1));
    }

    public String getReason() {
        return this.reason;
    }

    public A withReason(String reason) {
        this.reason=reason; return (A) this;
    }

    public Boolean hasReason() {
        return this.reason != null;
    }

    public A withNewReason(StringBuilder arg1) {
        return (A)withReason(new String(arg1));
    }

    public A withNewReason(int[] arg1,int arg2,int arg3) {
        return (A)withReason(new String(arg1, arg2, arg3));
    }

    public A withNewReason(char[] arg1) {
        return (A)withReason(new String(arg1));
    }

    public A withNewReason(StringBuffer arg1) {
        return (A)withReason(new String(arg1));
    }

    public A withNewReason(byte[] arg1,int arg2) {
        return (A)withReason(new String(arg1, arg2));
    }

    public A withNewReason(byte[] arg1) {
        return (A)withReason(new String(arg1));
    }

    public A withNewReason(char[] arg1,int arg2,int arg3) {
        return (A)withReason(new String(arg1, arg2, arg3));
    }

    public A withNewReason(byte[] arg1,int arg2,int arg3) {
        return (A)withReason(new String(arg1, arg2, arg3));
    }

    public A withNewReason(byte[] arg1,int arg2,int arg3,int arg4) {
        return (A)withReason(new String(arg1, arg2, arg3, arg4));
    }

    public A withNewReason(String arg1) {
        return (A)withReason(new String(arg1));
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        ContainerStateWaitingFluentImpl that = (ContainerStateWaitingFluentImpl) o;
        if (message != null ? !message.equals(that.message) :that.message != null) return false;
        if (reason != null ? !reason.equals(that.reason) :that.reason != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(message,  reason,  super.hashCode());
    }

}
